@@ -1,3 +1,8 @@
+# 本次更新内容：
+# 1、help（）函数中加入      print('#de_to_one_hot_auto(labels)')
+# 2、draw_result()函数中如果savepath=None，则不保存，只绘制
+
+
 import numpy as np
 import matplotlib.pyplot as plt
 from sklearn.metrics import confusion_matrix
@@ -11,11 +16,12 @@ def help():
     print('#to_one_hot(labels, dimension=2, begin=1)')
     print('#de_to_one_hot_3dim(labels)')
     print('#de_to_one_hot(labels)')
+    print('#de_to_one_hot_auto(labels)')
     print('#random_split(all_num, train_ratio, validation_ratio, test_ratio)')
 
 
 # 绘制loss以及acc的图
-def draw_result(history, savepath):
+def draw_result(history, savepath=None):
     acc = history['acc']
     val_acc = history['val_acc']
     loss = history['loss']
@@ -29,7 +35,8 @@ def draw_result(history, savepath):
     plt.plot(epochs, val_acc, 'r', label='Validation acc')
     plt.title('Training and validation accuracy')
     plt.legend()
-    plt.savefig(savepath + 'acc.jpg', dpi=200, bbox_inches='tight')
+    if savepath is not None:
+        plt.savefig(savepath + 'acc.jpg', dpi=200, bbox_inches='tight')
 
     plt.figure()
     plt.xlabel("Epoch")
@@ -38,7 +45,8 @@ def draw_result(history, savepath):
     plt.plot(epochs, val_loss, 'r', label='Validation loss')
     plt.title('Training and validation loss')
     plt.legend()
-    plt.savefig(savepath + 'loss.jpg', dpi=200, bbox_inches='tight')
+    if savepath is not None:
+        plt.savefig(savepath + 'loss.jpg', dpi=200, bbox_inches='tight')
 
     plt.show()
 
